@@ -11,7 +11,7 @@ class Contract(serializers.Serializer):
 
     def is_valid(self, raise_exception=False):
         try:
-            return super().is_valid(raise_exception)
+            return super().is_valid(raise_exception=raise_exception)
         except serializers.ValidationError as e:
             raise ContractError(e.detail)
 
